import { URI } from '@vscode/base-node/vs/base/common/uri';
export declare enum FileOperation {
    CREATE = 0,
    DELETE = 1,
    MOVE = 2,
    COPY = 3
}
export interface IStat {
    id?: number | string;
    type: FileType;
    mtime: number;
    ctime: number;
    size: number;
}
export declare enum FileType {
    Unknown = 0,
    File = 1,
    Directory = 2,
    SymbolicLink = 64
}
export declare enum FileKind {
    FILE = 0,
    FOLDER = 1,
    ROOT_FOLDER = 2
}
export interface IEncodingOverride {
    resource: URI;
    encoding: string;
}
export declare enum FileChangeType {
    UPDATED = 0,
    ADDED = 1,
    DELETED = 2
}
export interface IFileChange {
    type: FileChangeType;
    resource: URI;
}
export interface ICoreBaseStat {
    resource: URI | string;
    name?: string;
    title?: string;
    mtime?: number;
    etag?: string;
    isReadonly?: boolean;
}
export interface ICoreFileStat extends ICoreBaseStat {
    isDirectory: boolean;
    hasChildren?: boolean;
    children?: ICoreFileStat[];
}
export interface IFileOperationResult {
    message: string;
    fileOperationResult: FileOperationResult;
}
export declare enum FileOperationResult {
    FILE_IS_BINARY = 0,
    FILE_IS_DIRECTORY = 1,
    FILE_NOT_FOUND = 2,
    FILE_NOT_MODIFIED_SINCE = 3,
    FILE_MODIFIED_SINCE = 4,
    FILE_MOVE_CONFLICT = 5,
    FILE_READ_ONLY = 6,
    FILE_PERMISSION_DENIED = 7,
    FILE_TOO_LARGE = 8,
    FILE_INVALID_PATH = 9,
    FILE_EXCEED_MEMORY_LIMIT = 10
}
export declare const AutoSaveConfiguration: {
    OFF: string;
    AFTER_DELAY: string;
    ON_FOCUS_CHANGE: string;
    ON_WINDOW_CHANGE: string;
};
export declare const HotExitConfiguration: {
    OFF: string;
    ON_EXIT: string;
    ON_EXIT_AND_WINDOW_CLOSE: string;
};
export interface IProgress<T> {
    report(item: T): void;
}
export declare const enum FileSystemProviderCapabilities {
    FileReadWrite = 2,
    FileOpenReadWriteClose = 4,
    FileFolderCopy = 8,
    PathCaseSensitive = 1024,
    Readonly = 2048
}
